==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/sr-CS/general.php <==
<?php

    return [
    'accessories'			=> 'Dodatna oprema',
    'activated'			    => 'Aktiviran',
    'accessory'				=> 'Accessory',
    'accessory_report'		=> 'Accessory Report',
    'action'                => 'Akcija',
    'activity_report'		=> 'Izveštaj o aktivnostima',
    'address'				=> 'Adresa',
    'admin'					=> 'Admin',
    'administrator'			=> 'Administrator',
    'add_seats'             => 'Dodana mesta',
    'all_assets'			=> 'Sve imovine',
    'all'       			=> 'Sve',
    'archived'              => 'Arhivirano',
    'asset_models'			=> 'Modeli imovine',
    'asset_model'			=> 'Model',
    'asset'					=> 'Imovina',
    'asset_report'          => 'Izveštaj o imovini',
    'asset_tag'				=> 'Oznaka imovine',
    'assets_available'		=> 'dostupna imovina',
    'audit'				    => 'Revizija',
    'audit_report'			=> 'Zapisnik revizije',
    'assets'				=> 'Imovina',
    'avatar_delete'         => 'Obriši avatar',
    'avatar_upload'         => 'Učitaj avatar',
    'back'      			=> 'Nazad',
    'bad_data'      		=> 'Ništa nije pronađeno. Možda loši podaci?',
    'bulkaudit'             => 'Skupna revizija',
    'bulkaudit_status'      => 'Status revizije',
    'bulk_checkout'  		=> 'Bulk Checkout',
    'bystatus'              => 'by Status',
    'cancel'  				=> 'Otkazati',
    'categories'			=> 'Kategorije',
    'category'				=> 'Kategorija',
    'change' 		        => 'In / Out',
    'changeemail'  			=> 'Promeni email adresu',
    'changepassword'  		=> 'Promeni lozinku',
    'checkin'  				=> 'Checkin',
    'checkin_from'  		=> 'Checkin from',
    'checkout'  			=> 'Checkout',
    'checkouts_count'       => 'Checkouts',
    'checkins_count'        => 'Checkins',
    'user_requests_count'   => 'Zahtevi',
    'city'  				=> 'Grad',
	'click_here'			=> 'Kliknite ovde',
    'clear_selection'		=> 'Poništi izbor',
    'companies'			    => 'Firme',
    'company'				=> 'Firma',
    'component'			    => 'Komponenta',
    'components'			=> 'Komponente',
	'complete'				=> 'Završeno',
    'consumable'			=> 'Potrošni materijal',
    'consumables'			=> 'Potrošni materijal',
    'country'  				=> 'Zemlja',
    'create'				=> 'Napravi novi unos',
    'created'               => 'Stavka kreirana',
    'created_asset'			=> 'kreirana imovina',
    'created_at' 			=> 'Created at',
    'record_created' 		=> 'Record Created',
    'updated_at' 			=> 'Ažurirano',
    'currency'  			=> '$', // this is deprecated
    'current'  				=> 'Current',
    'custom_report'         => 'Prilagođeni izveštaj o imovini',
    'dashboard'				=> 'Dashboard',
    'days'      			=> 'dana',
    'days_to_next_audit'    => 'Dana do sledeće revizije',
    'date'					=> 'Datum',
    'debug_warning'         => 'Upozorenje!',
    'debug_warning_text'    => 'This application is running in production mode with debugging enabled. This can expose sensitive data if your application is accessible to the outside world. Disable debug mode by setting the <code>APP_DEBUG</code> value in your <code>.env</code> file to <code>false</code>.',
    'delete'  				=> 'Izbrisati',
    'delete_confirm'  		=> 'Jeste li sigurni da želite izbrisati :item?',
    'deleted'  				=> 'Izbrisano',
    'delete_seats'  		=> 'Izbrisana mesta',
    'departments'           => 'Departments',
    'department'           => 'Department',
    'deployed'				=> 'Razmešteno',
    'depreciation_report'	=> 'Izvještaj o amortizaciji',
    'details'               => 'Detalji',
    'download'				=> 'Download',
    'download_all'				=> 'Download All',
    'depreciation'			=> 'Amortizacija',
    'editprofile'  			=> 'Uredi svoj profil',
    'eol'					=> 'EOL',
    'email_domain'			=> 'Email Domain',
    'email_format'			=> 'Email Format',
    'email_domain_help'		=> 'Ovo se koristi za generisanje e-mail adrese prilikom uvoza',
    'filastname_format'			=> 'Prvo slovo imena Prezime (jsmith@example.com)',
    'firstname_lastname_format'	=> 'Ime Prezime (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => 'Ime Prezime (jane_smith@example.com)',
    'lastnamefirstinitial_format' =>  'Prezime Prvo slovo imena (smithj@example.com)',
    'firstintial_dot_lastname_format' => 'First Initial Last Name (j.smith@example.com)',
    'first'					=> 'Prvi',
    'firstnamelastname'     => 'First Name Last Name (janesmith@example.com)',
    'lastname_firstinitial' => 'Last Name First Initial (smith_j@example.com)',
    'firstinitial.lastname' => 'First Initial Last Name (j.smith@example.com)',
    'firstnamelastinitial'  => 'First Name Last Initial (janes@example.com)',
    'first_name'			=> 'Ime',
    'first_name_format'		=> 'Ime (jane@example.com)',
    'files'                 => 'Datoteke',
    'file_name'				=> 'Datoteka',
    'file_type'             => 'File Type',
    'file_uploads'			=> 'Prenos datoteka',
    'generate'				=> 'Generate',
     'github_markdown'      => 'This field accepts <a href="https://help.github.com/articles/github-flavored-markdown/">Github flavored markdown</a>.',
    'groups'				=> 'Grupe',
    'gravatar_email'        => 'Gravatar Email Address',
    'history'  			    => 'History',
    'history_for'  			=> 'History for',
    'id'  					=> 'ID',
    'image'                 => 'Slika',
    'image_delete'         	=> 'Izbriši sliku',
    'image_upload'         	=> 'Upload Image',
    'image_filetypes_help'  => 'Accepted filetypes are jpg, webp, png, gif, and svg. Max upload size allowed is :size.',
    'import'         	    => 'Import',
    'importing'         	=> 'Importing',
    'importing_help'        => 'You can import assets, accessories, licenses, components, consumables, and users via CSV file. <br><br>The CSV should be comma-delimited and formatted with headers that match the ones in the <a href="https://snipe-it.readme.io/docs/importing" target="_new">sample CSVs in the documentation</a>.',
    'import-history'        => 'Import History',
    'asset_maintenance'        => 'Održavanje imovine',
    'asset_maintenance_report' => 'Izveštaj o održavanju imovine',
    'asset_maintenances'       => 'Asset Maintenances',
    'item'  				=> 'Artikal',
    'insufficient_permissions' => 'Nedovoljna dozvola!',
    'kits'       			=> 'Predefined Kits',
    'language'				=> 'Jezik',
    'last'					=> 'Poslednji',
    'last_login'            => 'Poslednja prijava',
    'last_name'             => 'Prezime',
    'license'				=> 'Licenca',
    'license_report'        => 'Izveštaj o licenci',
    'licenses_available'	=> 'dostupne licence',
    'licenses'				=> 'Licence',
    'list_all'				=> 'Lista svih',
    'loading'				=> 'Loading',
    'lock_passwords'        => 'This field value will not be saved in a demo installation.',
    'feature_disabled'      => 'This feature has been disabled for the demo installation.',
    'location'              => 'Lokacija',
    'locations'				=> 'Lokacije',
    'logo_size'				=> 'Square logos look best with Logo + Text. Logo maximum display size is 50px high x 500px wide.  ',
    'logout'				=> 'Logout',
    'lookup_by_tag'     => 'Pretraživanje pomoću oznake imovine',
    'maintenances'          => 'Održavanje',
    'manufacturer'			=> 'Proizvođač',
    'manufacturers'			=> 'Proizvođači',
    'markdown'				=> 'Ovo polje dopušta <a href="https://help.github.com/articles/github-flavored-markdown/">Github verziju markdown</a>.',
    'min_amt'				=> 'Min. Kol',
    'min_amt_help'	=> 'Minimalni broj stavki koje bi trebale biti dostupne prije nego što se aktivira upozorenje.',
    'model_no'				=> 'Model br.',
    'months'				=> 'meseci',
    'moreinfo'				=> 'Više informacija',
    'name'					=> 'Ime',
    'next'					=> 'Sledeći',
    'next_audit_date'		=> 'Sledeći datum revizije',
    'last_audit'		    => 'Poslednja revizija',
    'new'					=> 'novi!',
    'no_depreciation'		=> 'Nema amortizacije',
    'no_results'			=> 'Nema rezultata.',
    'no'  					=> 'Ne',
    'notes'  				=> 'Zabeleške',
    'order_number'          => 'Broj narudžbe',
    'page_menu'				=> 'Showing _MENU_ items',
    'pagination_info'		=> 'Showing _START_ to _END_ of _TOTAL_ items',
    'pending'				=> 'Na čekanju',
    'people'				=> 'Ljudi',
    'per_page'				=> 'Rezultati po stranici',
    'previous'				=> 'Prethodna',
    'processing'			=> 'Obrađuje se',
    'profile'				=> 'Vaš profil',
    'purchase_cost'                              => 'Trošak nabavke',
    'purchase_date'         => 'Datum kupovine',
    'qty'		            => 'KOL',
    'quantity'		        => 'Količina',
    'ready_to_deploy'		=> 'Spremna za raspoređivanje',
    'recent_activity'		=> 'Nedavna aktivnost',
    'remove_company'        => 'Ukloni asocijaciju sa firmom',
    'reports'				=> 'Izveštaji',
    'restored'				=> 'vraćeno u prethodno stanje',
    'requested'				=> 'Tražena',
    'request_canceled'      => 'Zahtev je otkazan',
    'save'  				=> 'Sačuvaj',
    'select'				=> 'Označi',
    'search'				=> 'Pretraga',
    'select_category'       => 'Izaberite kategoriju',
    'select_department'       => 'Izaberite odeljenje',
    'select_depreciation'	=> 'Izaberite vrstu amortizacije',
    'select_location'		=> 'Izaberite lokaciju',
    'select_manufacturer'	=> 'Izaberite proizvođača',
    'select_model'			=> 'Izaberite Model',
    'select_supplier'		=> 'Odaberite dobavljača',
    'select_user'			=> 'Izaberite Korisnika',
    'select_date'			=> 'Izaberite Datum (GGGG-MM-DD)',
    'select_statuslabel'	=> 'Izaberite Status',
    'select_company'    	=> 'Odaberite Firmu',
    'select_asset'    		=> 'Odaberi sredstvo',
    'settings'				=> 'Podešavanja',
    'show_deleted'  		=> 'Prikaži Izbrisane',
    'show_current'  		=> 'Prikaži Trenutne',
    'sign_in'				=> 'Prijavite se',
    'signature'             => 'Potpis',
    'skin'       			=> 'Izgledi',
    'slack_test_msg'        => 'Oh hai! Looks like your Slack integration with Snipe-IT is working!',
    'some_features_disabled' => 'DEMO MOD: Neke funkcije su onemogućene za ovu instalaciju.',
    'site_name'				=> 'Naziv sajta',
    'state'  				=> 'Savezna država',
    'status_labels'			=> 'Oznake Statusa',
    'status'    			=> 'Status',
    'supplier'              => 'Dobavljač',
    'suppliers'  			=> 'Dobavljači',
    'sure_to_delete'    => 'Da li ste sigurni da želite izbrisati',
    'submit'				=> 'Submit',
    'target'                => 'Cilj',
    'time_and_date_display' => 'Prikaz vremena i datuma',
    'total_assets'			=> 'ukupna imovina',
    'total_licenses'		=> 'ukupne licence',
    'total_accessories'		=> 'ukupni pribor',
    'total_consumables'		=> 'ukupni potrošni materijal',
    'type'  				=> 'Tip',
    'undeployable'			=> 'Un-deployable',
    'unknown_admin'			=> 'Nepoznati administrator',
    'username_format'		=> 'Format korisničkog imena',
    'update'                => 'Ažuriraj',
    'upload_filetypes_help'      => 'Allowed filetypes are png, gif, jpg, jpeg, doc, docx, pdf, xls, xlsx, txt, lic, xml, zip, rtf and rar. Max upload size allowed is :size.',
    'uploaded'              => 'Uploaded',
    'user'					=> 'Korisnik',
    'accepted'			    => 'accepted',
    'declined'			    => 'declined',
    'unaccepted_asset_report' => 'Neprihvaćene imovine',
    'users'                 => 'Korisnici',
    'viewall'				=> 'View All',
    'viewassets'  			=> 'Prikaz dodijeljene imovine',
    'website'               => 'Website',
    'welcome'				=> 'Dobrodošli, :name',
    'years'					=> 'godine',
    'yes' 					=> 'Da',
    'zip'  					=> 'Zip',
    'noimage'				=> 'Nije prenesena slika ili slika nije pronađena.',
    'token_expired'         => 'Sesija za obrazac je istekla. Molim pokušajte ponovo.',
    'login_enabled'         => 'Login Enabled',
    'audit_due'             => 'Due for Audit',
    'audit_overdue'         => 'Overdue for Audit',
    'accept'                => 'Accept :asset',
    'i_accept'              => 'I accept',
    'i_decline'             => 'I decline',
    'sign_tos'              => 'Sign below to indicate that you agree to the terms of service:',
    'clear_signature'       => 'Clear Signature',
    'show_help'             => 'Show help',
    'hide_help'             => 'Hide help',
    ];

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/sr-CS/general.php <==
<?php

    return [
    'accessories'			=> 'Dodatna oprema',
    'activated'			    => 'Aktiviran',
    'accessory'				=> 'Accessory',
    'accessory_report'		=> 'Accessory Report',
    'action'                => 'Akcija',
    'activity_report'		=> 'Izveštaj o aktivnostima',
    'address'				=> 'Adresa',
    'admin'					=> 'Admin',
    'administrator'			=> 'Administrator',
    'add_seats'             => 'Dodana mesta',
    'all_assets'			=> 'Sve imovine',
    'all'       			=> 'Sve',
    'archived'              => 'Arhivirano',
    'asset_models'			=> 'Modeli imovine',
    'asset_model'			=> 'Model',
    'asset'					=> 'Imovina',
    'asset_report'          => 'Izveštaj o imovini',
    'asset_tag'				=> 'Oznaka imovine',
    'asset_tags'            => 'Asset Tags',
    'assets_available'		=> 'Assets available',
    'accept_assets'         => 'Accept Assets :name',
    'accept_assets_menu'    => 'Accept Assets',
    'audit'				    => 'Revizija',
    'audit_report'			=> 'Zapisnik revizije',
    'assets'				=> 'Imovina',
    'avatar_delete'         => 'Obriši avatar',
    'avatar_upload'         => 'Učitaj avatar',
    'back'      			=> 'Nazad',
    'bad_data'      		=> 'Ništa nije pronađeno. Možda loši podaci?',
    'bulkaudit'             => 'Skupna revizija',
    'bulkaudit_status'      => 'Status revizije',
    'bulk_checkout'  		=> 'Bulk Checkout',
    'bulk_edit'             => 'Bulk Edit',
    'bulk_delete'           => 'Bulk Delete',
    'bulk_actions'          => 'Bulk Actions',
    'bulk_checkin_delete'   => 'Bulk Checkin &amp; Delete',
    'bystatus'              => 'by Status',
    'cancel'  				=> 'Otkazati',
    'categories'			=> 'Kategorije',
    'category'				=> 'Kategorija',
    'change' 		        => 'In / Out',
    'changeemail'  			=> 'Promeni email adresu',
    'changepassword'  		=> 'Promeni lozinku',
    'checkin'  				=> 'Checkin',
    'checkin_from'  		=> 'Checkin from',
    'checkout'  			=> 'Checkout',
    'checkouts_count'       => 'Checkouts',
    'checkins_count'        => 'Checkins',
    'user_requests_count'   => 'Zahtevi',
    'city'  				=> 'Grad',
    'click_here'			=> 'Kliknite ovde',
    'clear_selection'		=> 'Poništi izbor',
    'companies'			    => 'Firme',
    'company'				=> 'Firma',
    'component'			    => 'Komponenta',
    'components'			=> 'Komponente',
    'complete'				=> 'Završeno',
    'consumable'			=> 'Potrošni materijal',
    'consumables'			=> 'Potrošni materijal',
    'country'  				=> 'Zemlja',
    'create'				=> 'Napravi novi unos',
    'created'               => 'Stavka kreirana',
    'created_asset'			=> 'kreirana imovina',
    'created_at' 			=> 'Created at',
    'record_created' 		=> 'Record Created',
    'updated_at' 			=> 'Ažurirano',
    'currency'  			=> '$', // this is deprecated
    'current'  				=> 'Current',
    'current_password'      => 'Current Password',
    'customize_report'      => 'Customize Report',
    'custom_report'         => 'Prilagođeni izveštaj o imovini',
    'dashboard'				=> 'Dashboard',
    'days'      			=> 'dana',
    'days_to_next_audit'    => 'Dana do sledeće revizije',
    'date'					=> 'Datum',
    'debug_warning'         => 'Upozorenje!',
    'debug_warning_text'    => 'This application is running in production mode with debugging enabled. This can expose sensitive data if your application is accessible to the outside world. Disable debug mode by setting the <code>APP_DEBUG</code> value in your <code>.env</code> file to <code>false</code>.',
    'delete'  				=> 'Izbrisati',
    'delete_confirm'  		=> 'Jeste li sigurni da želite izbrisati :item?',
    'deleted'  				=> 'Izbrisano',
    'delete_seats'  		=> 'Izbrisana mesta',
    'deletion_failed'       => 'Deletion failed',
    'departments'           => 'Departments',
    'department'            => 'Department',
    'deployed'				=> 'Razmešteno',
    'depreciation'			=> 'Amortizacija',
    'depreciations'         => 'Depreciations',
    'depreciation_report'	=> 'Izvještaj o amortizaciji',
    'details'               => 'Detalji',
    'download'				=> 'Download',
    'download_all'		    => 'Download All',
    'editprofile'  			=> 'Uredi svoj profil',
    'eol'					=> 'EOL',
    'email_domain'			=> 'Email Domain',
    'email_format'			=> 'Email Format',
    'employee_number'       => 'Employee Number',
    'email_domain_help'		=> 'Ovo se koristi za generisanje e-mail adrese prilikom uvoza',
    'error'				    => 'Error',
    'filastname_format'			=> 'Prvo slovo imena Prezime (jsmith@example.com)',
    'firstname_lastname_format'	=> 'Ime Prezime (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => 'Ime Prezime (jane_smith@example.com)',
    'lastnamefirstinitial_format' =>  'Prezime Prvo slovo imena (smithj@example.com)',
    'firstintial_dot_lastname_format' => 'First Initial Last Name (j.smith@example.com)',
    'first'					=> 'Prvi',
    'firstnamelastname'     => 'First Name Last Name (janesmith@example.com)',
    'lastname_firstinitial' => 'Last Name First Initial (smith_j@example.com)',
    'firstinitial.lastname' => 'First Initial Last Name (j.smith@example.com)',
    'firstnamelastinitial'  => 'First Name Last Initial (janes@example.com)',
    'first_name'			=> 'Ime',
    'first_name_format'		=> 'Ime (jane@example.com)',
    'files'                 => 'Datoteke',
    'file_name'				=> 'Datoteka',
    'file_type'             => 'File Type',
    'file_uploads'			=> 'Prenos datoteka',
    'file_upload'           => 'File Upload',
    'generate'				=> 'Generate',
    'generate_labels'       => 'Generate Labels',
    'github_markdown'      => 'This field accepts <a href="https://help.github.com/articles/github-flavored-markdown/">Github flavored markdown</a>.',
    'groups'				=> 'Grupe',
    'gravatar_email'        => 'Gravatar Email Address',
    'gravatar_url'          => '<a href="http://gravatar.com"><small>Change your avatar at Gravatar.com</small></a>.',
    'history'  			    => 'History',
    'history_for'  			=> 'History for',
    'id'  					=> 'ID',
    'image'                 => 'Slika',
    'image_delete'         	=> 'Izbriši sliku',
    'image_upload'         	=> 'Upload Image',
    'filetypes_accepted_help'    => 'Accepted filetype is :types. Max upload size allowed is :size.|Accepted filetypes are :types. Max upload size allowed is :size.',
    'filetypes_size_help'   => 'Max upload size allowed is :size.',
    'image_filetypes_help'  => 'Accepted filetypes are jpg, webp, png, gif, and svg. Max upload size allowed is :size.',
    'import'         	    => 'Import',
    'importing'         	=> 'Importing',
    'importing_help'        => 'You can import assets, accessories, licenses, components, consumables, and users via CSV file. <br><br>The CSV should be comma-delimited and formatted with headers that match the ones in the <a href="https://snipe-it.readme.io/docs/importing" target="_new">sample CSVs in the documentation</a>.',
    'import-history'        => 'Import History',
    'asset_maintenance'        => 'Održavanje imovine',
    'asset_maintenance_report' => 'Izveštaj o održavanju imovine',
    'asset_maintenances'       => 'Asset Maintenances',
    'item'  				=> 'Artikal',
    'item_name'             => 'Item Name',
    'insufficient_permissions' => 'Nedovoljna dozvola!',
    'kits'       			=> 'Predefined Kits',
    'language'				=> 'Jezik',
    'last'					=> 'Poslednji',
    'last_login'            => 'Poslednja prijava',
    'last_name'             => 'Prezime',
    'license'				=> 'Licenca',
    'license_report'        => 'Izveštaj o licenci',
    'licenses_available'	=> 'dostupne licence',
    'licenses'				=> 'Licence',
    'list_all'				=> 'Lista svih',
    'loading'				=> 'Loading... please wait....',
    'lock_passwords'        => 'This field value will not be saved in a demo installation.',
    'feature_disabled'      => 'This feature has been disabled for the demo installation.',
    'location'              => 'Lokacija',
    'locations'				=> 'Lokacije',
    'logo_size'				=> 'Square logos look best with Logo + Text. Logo maximum display size is 50px high x 500px wide.  ',
    'logout'				=> 'Logout',
    'lookup_by_tag'     => 'Pretraživanje pomoću oznake imovine',
    'maintenances'          => 'Održavanje',
    'manage_api_keys'       => 'Manage API Keys',
    'manufacturer'			=> 'Proizvođač',
    'manufacturers'			=> 'Proizvođači',
    'markdown'				=> 'Ovo polje dopušta <a href="https://help.github.com/articles/github-flavored-markdown/">Github verziju markdown</a>.',
    'min_amt'				=> 'Min. Kol',
    'min_amt_help'          => 'Minimum number of items that should be available before an alert gets triggered. Leave Min. QTY blank if you do not want to receive alerts for low inventory.',
    'model_no'				=> 'Model br.',
    'months'				=> 'meseci',
    'moreinfo'				=> 'Više informacija',
    'name'					=> 'Ime',
    'new_password'          => 'New Password',
    'next'					=> 'Sledeći',
    'next_audit_date'		=> 'Sledeći datum revizije',
    'last_audit'		    => 'Poslednja revizija',
    'new'					=> 'novi!',
    'no_depreciation'		=> 'Nema amortizacije',
    'no_results'			=> 'Nema rezultata.',
    'no'  					=> 'Ne',
    'notes'  				=> 'Zabeleške',
    'order_number'          => 'Broj narudžbe',
    'page_menu'				=> 'Showing _MENU_ items',
    'pagination_info'		=> 'Showing _START_ to _END_ of _TOTAL_ items',
    'pending'				=> 'Na čekanju',
    'people'				=> 'Ljudi',
    'per_page'				=> 'Rezultati po stranici',
    'previous'				=> 'Prethodna',
    'processing'			=> 'Obrađuje se',
    'profile'				=> 'Vaš profil',
    'purchase_cost'                              => 'Trošak nabavke',
    'purchase_date'         => 'Datum kupovine',
    'qty'		            => 'KOL',
    'quantity'		        => 'Količina',
    'quantity_minimum'      => 'You have :count items below or almost below minimum quantity levels',
    'quickscan_checkin'  	=> 'Quick Scan Checkin',
    'quickscan_checkin_status'  	=> 'Checkin Status',
    'ready_to_deploy'		=> 'Spremna za raspoređivanje',
    'recent_activity'		=> 'Nedavna aktivnost',
    'remaining'             => 'Remaining',
    'remove_company'        => 'Ukloni asocijaciju sa firmom',
    'reports'				=> 'Izveštaji',
    'restored'				=> 'vraćeno u prethodno stanje',
    'restore'				=> 'Restore',
    'requestable_models'    => 'Requestable Models',
    'requested'				=> 'Tražena',
    'requested_date'        => 'Requested Date',
    'requested_assets'      => 'Requested Assets',
    'requested_assets_menu' => 'Requested Assets',
    'request_canceled'      => 'Zahtev je otkazan',
    'save'  				=> 'Sačuvaj',
    'select'				=> 'Označi',
    'select_all'            => 'Select All',
    'search'				=> 'Pretraga',
    'select_category'       => 'Izaberite kategoriju',
    'select_department'     => 'Izaberite odeljenje',
    'select_depreciation'	=> 'Izaberite vrstu amortizacije',
    'select_location'		=> 'Izaberite lokaciju',
    'select_manufacturer'	=> 'Izaberite proizvođača',
    'select_model'			=> 'Izaberite Model',
    'select_supplier'		=> 'Odaberite dobavljača',
    'select_user'			=> 'Izaberite Korisnika',
    'select_date'			=> 'Izaberite Datum (GGGG-MM-DD)',
    'select_statuslabel'	=> 'Izaberite Status',
    'select_company'    	=> 'Odaberite Firmu',
    'select_asset'    		=> 'Odaberi sredstvo',
    'settings'				=> 'Podešavanja',
    'show_deleted'  		=> 'Prikaži Izbrisane',
    'show_current'  		=> 'Prikaži Trenutne',
    'sign_in'				=> 'Prijavite se',
    'signature'             => 'Potpis',
    'skin'       			=> 'Izgledi',
    'slack_msg_note'        => 'A slack message will be sent',
    'slack_test_msg'        => 'Oh hai! Looks like your Slack integration with Snipe-IT is working!',
    'some_features_disabled' => 'DEMO MOD: Neke funkcije su onemogućene za ovu instalaciju.',
    'site_name'				=> 'Naziv sajta',
    'state'  				=> 'Savezna država',
    'status_labels'			=> 'Oznake Statusa',
    'status'    			=> 'Status',
    'supplier'              => 'Dobavljač',
    'suppliers'  			=> 'Dobavljači',
    'sure_to_delete'    => 'Da li ste sigurni da želite izbrisati',
    'submit'				=> 'Submit',
    'target'                => 'Cilj',
    'toggle_navigation'     => 'Toogle Navigation',
    'time_and_date_display' => 'Prikaz vremena i datuma',
    'total_assets'			=> 'ukupna imovina',
    'total_licenses'		=> 'ukupne licence',
    'total_accessories'		=> 'ukupni pribor',
    'total_consumables'		=> 'ukupni potrošni materijal',
    'type'  				=> 'Tip',
    'undeployable'			=> 'Un-deployable',
    'unknown_admin'			=> 'Nepoznati administrator',
    'username_format'		=> 'Format korisničkog imena',
    'update'                => 'Ažuriraj',
    'upload_filetypes_help'      => 'Allowed filetypes are png, gif, jpg, jpeg, doc, docx, pdf, xls, xlsx, txt, lic, xml, zip, rtf and rar. Max upload size allowed is :size.',
    'uploaded'              => 'Uploaded',
    'user'					=> 'Korisnik',
    'accepted'			    => 'accepted',
    'declined'			    => 'declined',
    'unaccepted_asset_report' => 'Neprihvaćene imovine',
    'users'                 => 'Korisnici',
    'viewall'				=> 'View All',
    'viewassets'  			=> 'Prikaz dodijeljene imovine',
    'viewassetsfor'         => 'View Assets for :name',
    'website'               => 'Website',
    'welcome'				=> 'Dobrodošli, :name',
    'years'					=> 'godine',
    'yes' 					=> 'Da',
    'zip'  					=> 'Zip',
    'noimage'				=> 'Nije prenesena slika ili slika nije pronađena.',
    'token_expired'         => 'Sesija za obrazac je istekla. Molim pokušajte ponovo.',
    'login_enabled'         => 'Login Enabled',
    'audit_due'             => 'Due for Audit',
    'audit_overdue'         => 'Overdue for Audit',
    'accept'                => 'Accept :asset',
    'i_accept'              => 'I accept',
    'i_decline'             => 'I decline',
    'accept_decline'        => 'Accept/Decline',
    'sign_tos'              => 'Sign below to indicate that you agree to the terms of service:',
    'clear_signature'       => 'Clear Signature',
    'show_help'             => 'Show help',
    'hide_help'             => 'Hide help',
    'view_all'              => 'view all',
    'hide_deleted'          => 'Hide Deleted',
    'email'                 => 'Email',
    'do_not_change'         => 'Do Not Change',
    'bug_report'            => 'Report a Bug',
    'user_manual'           => 'User\'s Manual',
    'setup_step_1'          => 'Step 1',
    'setup_step_2'          => 'Step 2',
    'setup_step_3'          => 'Step 3',
    'setup_step_4'          => 'Step 4',
    'setup_config_check'    => 'Configuration Check',
    'setup_create_database' => 'Create Database Tables',
    'setup_create_admin'    => 'Create Admin User',
    'setup_done'            => 'Finished!',
    'bulk_edit_about_to'    => 'You are about to edit the following: ',
    'checked_out'           => 'Checked Out',
    'checked_out_to'        => 'Checked out to',
    'fields'                => 'Fields',
    'last_checkout'         => 'Last Checkout',
    'due_to_checkin'        => 'The following :count items are due to be checked in soon:',
    'expected_checkin'      => 'Expected Checkin',
    'reminder_checked_out_items' => 'This is a reminder of the items currently checked out to you. If you feel this list is inaccurate (something is missing, or something appears here that you believe you never received), please email :reply_to_name at :reply_to_address.',
    'changed'               => 'Changed',
    'to'                    => 'To',
    'report_fields_info'    => '<p>Select the fields you would like to include in your custom report, and click Generate. The file (custom-asset-report-YYYY-mm-dd.csv) will download automatically, and you can open it in Excel.</p>
            <p>If you would like to export only certain assets, use the options below to fine-tune your results.</p>',
    'range'                 => 'Range',
    'bom_remark'            => 'Add a BOM (byte-order mark) to this CSV',
    'improvements'          => 'Improvements',
    'information'           => 'Information',
    'permissions'           => 'Permissions',
    'managed_ldap'          => '(Managed via LDAP)',
    'export'                => 'Export',
    'ldap_sync'             => 'LDAP Sync',
    'ldap_user_sync'        => 'LDAP User Sync',
    'synchronize'           => 'Synchronize',
    'sync_results'          => 'Synchronization Results',
    'license_serial'        => 'Serial/Product Key',
    'invalid_category'      => 'Invalid category',
    'dashboard_info'        => 'This is your dashboard. There are many like it, but this one is yours.',
    '60_percent_warning'    => '60% Complete (warning)',
    'dashboard_empty'       => 'It looks like you haven not added anything yet, so we do not have anything awesome to display. Get started by adding some assets, accessories, consumables, or licenses now!',
    'new_asset'             => 'New Asset',
    'new_license'           => 'New License',
    'new_accessory'         => 'New Accessory',
    'new_consumable'        => 'New Consumable',
    'collapse'              => 'Collapse',
    'assigned'              => 'Assigned',
    'asset_count'           => 'Asset Count',
    'accessories_count'     => 'Accessories Count',
    'consumables_count'     => 'Consumables Count',
    'components_count'      => 'Components Count',
    'licenses_count'        => 'Licenses Count',
    'notification_error'    => 'Error:',
    'notification_error_hint' => 'Please check the form below for errors',
    'notification_success'  => 'Success:',
    'notification_warning'   => 'Warning:',
    'notification_info'      => 'Info:',
    'asset_information'     => 'Asset Information',
    'model_name'            => 'Model Name:',
    'asset_name'            => 'Asset Name:',
    'consumable_information' => 'Consumable Information:',
    'consumable_name'       => 'Consumable Name:',
    'accessory_information' => 'Accessory Information:',
    'accessory_name'       => 'Accessory Name:',
    'clone_item'            => 'Clone Item',
    'checkout_tooltip' => 'Check this item out',
    'checkin_tooltip' => 'Check this item in',
    'checkout_user_tooltip' => 'Check this item out to a user',
];
